summaryrefslogtreecommitdiffstats
path: root/iw
diff options
context:
space:
mode:
authorChris Lumens <clumens@redhat.com>2006-06-01 21:46:43 +0000
committerChris Lumens <clumens@redhat.com>2006-06-01 21:46:43 +0000
commit08be22b02d26d7480099df0674c300146e324591 (patch)
treef9a3b49be22c97d58bcf1f758bcff87477eb66cd /iw
parentec8ef51355464fa46c7efe3cdd89751424e51875 (diff)
downloadanaconda-08be22b02d26d7480099df0674c300146e324591.tar.gz
anaconda-08be22b02d26d7480099df0674c300146e324591.tar.xz
anaconda-08be22b02d26d7480099df0674c300146e324591.zip
If the volume group's physical extent size is other than what we expect, make
sure to add it to the list (#185272).
Diffstat (limited to 'iw')
-rw-r--r--iw/lvm_dialog_gui.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/iw/lvm_dialog_gui.py b/iw/lvm_dialog_gui.py
index 365efd686..bce7d3392 100644
--- a/iw/lvm_dialog_gui.py
+++ b/iw/lvm_dialog_gui.py
@@ -245,8 +245,8 @@ class VolumeGroupEditor:
defindex = None
actualPE = lvm.getPossiblePhysicalExtents(floor=1024)
for curpe in actualPE:
- # dont show PE over 128M
- if curpe > 131072:
+ # dont show PE over 128M, unless it's the default
+ if curpe > 131072 and curpe != default:
continue
val = self.prettyFormatPESize(curpe)